@@ -98,7 +98,7 @@ KMenu * ContextMenu::createTransferContextMenu(TransferHandler* handler, QWidget
 
 #ifdef HAVE_KONQUEROR
     // only shows the open with actions if the transfer is finished
-    if (handler->status() == Job::Finished) {
+    if (handler->status() == Job::Finished || handler->status() == Job::FinishedKeepAlive) {
         KFileItemList items;
         items << KFileItem(KFileItem::Unknown, KFileItem::Unknown, handler->dest());
 
@@ -134,16 +134,8 @@ KMenu * ContextMenu::createTransferGroupContextMenu(TransferGroupHandler *handle
     popup->addAction(KGet::actionCollection()->action("transfer_group_settings"));
     popup->addSeparator();
 
-    QList<TransferGroupHandler *> transferGroups = KGet::selectedTransferGroups();
-    bool containsMainGroup = false;
-    foreach(TransferGroupHandler *transHandler, transferGroups)
-    {
-        if(transHandler->name() == i18n("My Downloads"))
-        {
-            containsMainGroup = true;
-            break;
-        }
-    }
+    bool containsMainGroup;
+    QList<TransferGroupHandler *> transferGroups = KGet::selectedTransferGroups(&containsMainGroup);
     if(!containsMainGroup) {
         const int numGroups = transferGroups.count();
         QAction *action = KGet::actionCollection()->action("delete_groups");
